<?php
namespace Opencart\Admin\Controller\Extension\CoinPay\Payment;
class CoinPay extends \Opencart\System\Engine\Controller {
    public function index(): void {
        $this->load->language('extension/coinpay/payment/coinpay');

        $this->document->setTitle($this->language->get('heading_title'));

        $language = $this->config->get('config_language');

		$data['breadcrumbs'] = [];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'])
		];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_extensions'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment')
		];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/coinpay/payment/coinpay', 'user_token=' . $this->session->data['user_token'])
		];

        $data['save'] = $this->url->link('extension/coinpay/payment/coinpay|save', 'user_token=' . $this->session->data['user_token']);
        $data['back'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment');

        $this->load->model('localisation/geo_zone');
        $data['geo_zones'] = $this->model_localisation_geo_zone->getGeoZones();

        $this->load->model('localisation/order_status');
        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

        $data['payment_coinpay_merchant_id'] =  $this->config->get('payment_coinpay_merchant_id');
        $data['payment_coinpay_gateway'] =  $this->config->get('payment_coinpay_gateway');
        $data['payment_coinpay_geo_zone_id'] =  $this->config->get('payment_coinpay_geo_zone_id');
        $data['payment_coinpay_pending_status'] =  $this->config->get('payment_coinpay_pending_status');
        $data['payment_coinpay_paid_status'] =  $this->config->get('payment_coinpay_paid_status');
        $data['payment_coinpay_ipn_url'] = $this->config->get('payment_coinpay_ipn_url');
        $data['payment_coinpay_success_url'] = $this->config->get('payment_coinpay_success_url');

        if(empty($data['payment_coinpay_ipn_url'])) {
            $default_ipn_url = $this->url->link('extension/coinpay/payment/coinpay|callback', 'language=' . $language);
            $default_ipn_url = str_replace(HTTP_SERVER, HTTP_CATALOG, $default_ipn_url);
            if(defined('HTTPS_SERVER')) {
                $default_ipn_url = str_replace(HTTPS_SERVER, HTTPS_CATALOG, $default_ipn_url);
            }
            $default_ipn_url = $default_ipn_url;
            $data['payment_coinpay_ipn_url'] = $default_ipn_url;
        }

        if(empty($data['payment_coinpay_success_url'])) {
            $default_success_url = $this->url->link('extension/coinpay/payment/coinpay|success', 'language=' . $language);
            $default_success_url = str_replace(HTTP_SERVER, HTTP_CATALOG, $default_success_url);
            if(defined('HTTPS_SERVER')) {
                $default_success_url = str_replace(HTTPS_SERVER, HTTPS_CATALOG, $default_success_url);
            }
            $default_success_url = $default_success_url;
            $data['payment_coinpay_success_url'] = $default_success_url;
        }

        $data['payment_coinpay_status'] =  $this->config->get('payment_coinpay_status');
        $data['payment_coinpay_sort_order'] = $this->config->get('payment_coinpay_sort_order');

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');
        $this->response->setOutput($this->load->view('extension/coinpay/payment/coinpay', $data));
    }

    public function save(): void {
        $this->load->language('extension/coinpay/payment/coinpay');

        $json = [];

        if (!$this->request->post['payment_coinpay_merchant_id']) {
			$json['error']['merchant_id'] = $this->language->get('error_merchant_id');
		}

        if (!$this->request->post['payment_coinpay_gateway']) {
			$json['error']['gateway'] = $this->language->get('error_gateway');
		}

        if (!$json) {
            $this->load->model('setting/setting');
            $this->model_setting_setting->editSetting('payment_coinpay', $this->request->post);
            $json['success'] = $this->language->get('text_success');
        }

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));
    }
}