<?php 
namespace Opencart\Catalog\Controller\Extension\CoinPay\Payment;
class CoinPay extends \Opencart\System\Engine\Controller {
    private $error = [];
		
	public function __construct($registry) {
		parent::__construct($registry);

		if (version_compare(phpversion(), '7.1', '>=')) {
			ini_set('precision', 14);
			ini_set('serialize_precision', 14);
		}
	}

    public function index(): string {
        $data['button_confirm'] = $this->language->get('button_confirm');
        if (isset($this->session->data['error_coinpayment'])) {
			unset($this->session->data['error_coinpayment']);
		}

        $language = $this->config->get('config_language');

        $data['action'] = $this->config->get('payment_coinpay_gateway');

		$this->load->model('checkout/order');
		if (!isset($this->session->data['order_id'])) {
			$this->response->redirect($this->url->link('checkout/cart'));
			return '';
		}
		$order_info = $this->model_checkout_order->getOrder($this->session->data['order_id']);

        if ($order_info) {
            $total = $this->currency->format($order_info['total'], $order_info['currency_code'], false, false);

            $data['merchant'] = $this->config->get('payment_coinpay_merchant_id');
            $data['item_name'] = html_entity_decode($this->config->get('config_name'), ENT_QUOTES, 'UTF-8');

            $currency_code = $this->session->data['currency'];

			$item_info = [];
            foreach ($this->cart->getProducts() as $product) {
                $product_price = number_format($product['price'], 2, '.', '');
                    
                $item_info[] = [
                    'name' => $product['name'],
                    'sku' => $product['model'],
                    'url' => $this->url->link('product/product', 'language=' . $language . '&product_id=' . $product['product_id']),
                    'quantity' => $product['quantity'],
                    'unit_amount' => [
                        'currency_code' => $currency_code,
                        'value' => $product_price
                    ]
                ];
            }

            $data['amount'] = $total;
            $data['tax'] = 0.00;
            $data['shipping'] = 0.00;
            $data['products'] = $item_info;
            $data['currency_code'] = $currency_code;
            $data['first_name'] = html_entity_decode($order_info['shipping_firstname'], ENT_QUOTES, 'UTF-8');
            $data['last_name'] = html_entity_decode($order_info['shipping_lastname'], ENT_QUOTES, 'UTF-8');
            $data['address1'] = html_entity_decode($order_info['shipping_address_1'], ENT_QUOTES, 'UTF-8');	
			$data['address2'] = html_entity_decode($order_info['shipping_address_2'], ENT_QUOTES, 'UTF-8');
            $data['city'] = html_entity_decode($order_info['shipping_city'], ENT_QUOTES, 'UTF-8');
            $data['state'] = html_entity_decode($order_info['shipping_zone'], ENT_QUOTES, 'UTF-8');
            $data['zip'] = html_entity_decode($order_info['shipping_postcode'], ENT_QUOTES, 'UTF-8');
            $data['country'] = $order_info['shipping_country'];
            $data['phone'] = html_entity_decode($order_info['telephone'], ENT_QUOTES, 'UTF-8');
            $data['email'] = $order_info['email'];
            $data['invoice'] = $this->session->data['order_id'];
            $data['cancel_url'] = $this->url->link('checkout/checkout', 'language=' . $language , 'SSL');
            $data['success_url'] = $this->config->get('payment_coinpay_success_url');
            $data['ipn_url'] = $this->config->get('payment_coinpay_ipn_url');
            $data['custom'] = $this->session->data['order_id'];
            $data['language'] = $this->config->get('config_language');
        }
        
        return $this->load->view('extension/coinpay/payment/coinpay', $data);
    }

    public function confirm(): void {
		$this->load->language('extension/coinpay/payment/coinpay');

		$json = [];

		if (!isset($this->session->data['order_id'])) {
			$json['error'] = $this->language->get('error_order');
		}

		if (!isset($this->session->data['payment_method']) || $this->session->data['payment_method'] != 'coinpay') {
			$json['error'] = $this->language->get('error_payment_method');
		}

		if (!$json) {
			$json['success'] = true;
		}

        $this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
    }

    public function success() {
        $this->load->language('extension/coinpay/payment/coinpay');

        $comment  = $this->language->get('text_payment');
        $redirect = $this->url->link('checkout/success?language=' . $this->config->get('config_language'));
        $order_id_status = $this->config->get('payment_coinpay_pending_status');

		$this->load->model('checkout/order');
		$order_id = $this->session->data['order_id'];
		if (is_null($order_id)) {
			$this->response->redirect($redirect);
			return;
		}

		// Progress the order status
		$this->model_checkout_order->addHistory($order_id, $order_id_status, $comment, true);
		$this->response->redirect($redirect);
    }

    public function callback() {
        if (isset($this->request->post['invoice'])) {
            $order_id = $this->request->post['invoice'];
        } else {
            $order_id = 0;
        }

        $status = $this->request->post['status'];
        $status_text = $this->request->post['status_text'];
        $txn_id = $this->request->post['txn_id'];

        $this->load->model('checkout/order');
        $order_info = $this->model_checkout_order->getOrder($order_id);
        if ($order_info) {
            if ($status == 2) {
                $order_status_id = $this->config->get('payment_coinpay_paid_status');
            } else {
                $order_status_id = $this->config->get('payment_coinpay_pending_status');
            }
            if ($order_status_id) {
                $comment = 'Status: ' . $status_text . "\nPayment ID: " . $txn_id;
                $this->model_checkout_order->addHistory($order_id, $order_status_id, $comment, true);
            }
        }
    }
}